// src/hooks.tsx
import React4 from "react";
import { formatISO } from "date-fns";
import invariant from "tiny-invariant";
import { httpsCallable } from "firebase/functions";
import { useDocumentData } from "react-firebase-hooks/firestore";
import { doc as doc2, getDoc } from "firebase/firestore";
import { useRefConverter } from "@usereactify/app";

// src/provider.tsx
import React3 from "react";
import { getFunctions } from "firebase/functions";
import { doc, getFirestore } from "firebase/firestore";

// src/components/TaskModal.tsx
import React2 from "react";
import { ReplayMinor } from "@shopify/polaris-icons";
import {
  Modal,
  Stack as Stack2,
  Heading,
  TextContainer
} from "@shopify/polaris";

// src/components/LogViewer.tsx
import { format } from "date-fns";
import { Icon, Stack, Spinner, TextStyle } from "@shopify/polaris";
import {
  ViewMinor,
  RiskMinor,
  AlertMinor,
  ChevronRightMinor
} from "@shopify/polaris-icons";
var LogViewer = ({ task }) => {
  const { status, logEntries } = useTaskLogs({
    taskPath: task.ref.path,
    searchFromDate: task.createdAt.toDate()
  });
  return <div className="taskify-log-viewer">
    {("undefined" === typeof status || "NO_LOGS_FOUND" === status) && <Stack>
      <Spinner size="small" />
      <p>{"Waiting for logs\u2026"}</p>
    </Stack>}
    {"EMULATOR" === status && <Stack>
      <Icon source={ViewMinor} color="base" />
      <p>Look at the emulator console output for logs.</p>
    </Stack>}
    {"LOGS_FOUND" === status && !!logEntries && <Stack spacing="tight" vertical>{logEntries.map((logEntry) => <Stack wrap={false} spacing="tight" alignment="leading" key={logEntry.insertId}>
      <p className="taskify-log-viewer__time">{format(new Date(logEntry.timestamp), "HH:mm:ss")}</p>
      <Stack.Item><LogEntryIcon logEntry={logEntry} /></Stack.Item>
      <Stack.Item fill><LogEntryMessage logEntry={logEntry} /></Stack.Item>
    </Stack>)}</Stack>}
  </div>;
};
var LogEntryIcon = ({ logEntry }) => {
  if ("ERROR" === logEntry.severity)
    return <Icon source={AlertMinor} color="critical" />;
  if ("WARN" === logEntry.severity)
    return <Icon source={RiskMinor} color="warning" />;
  return <Icon source={ChevronRightMinor} color="subdued" />;
};
var LogEntryMessage = ({ logEntry }) => {
  if ("ERROR" === logEntry.severity)
    return <p><TextStyle variation="negative">{logEntry.message}</TextStyle></p>;
  if ("DEBUG" === logEntry.severity)
    return <p><TextStyle variation="subdued">{logEntry.message}</TextStyle></p>;
  return <p>{logEntry.message}</p>;
};

// src/components/StatusBadge.tsx
import React from "react";
import { Badge } from "@shopify/polaris";
var StatusBadge = ({ status }) => {
  const statusBadgeProps = React.useMemo(() => {
    if (!status)
      return {};
    if ("PENDING" === status)
      return { status: "new", progress: "incomplete" };
    if ("RUNNING" === status)
      return { status: "info", progress: "partiallyComplete" };
    if ("COMPLETE" === status)
      return { status: "success", progress: "complete" };
    if (["FAILED", "TIMEOUT"].includes(status))
      return { status: "critical", progress: "complete" };
    return { status: "info" };
  }, [status]);
  return <Badge size="medium" {...statusBadgeProps}>{status.toLowerCase()}</Badge>;
};

// src/components/TaskModal.tsx
var TaskModal = ({ open, taskPath, onClose }) => {
  const { task, loading } = useTask(taskPath);
  const retryTask = useRetryTask();
  const primaryAction = React2.useMemo(() => {
    if (!task)
      return void 0;
    return {
      icon: ReplayMinor,
      content: "Retry",
      onAction: () => retryTask({ originalTaskPath: task.ref.path }),
      disabled: !["FAILED", "TIMEOUT", "COMPLETE"].includes(task.status)
    };
  }, [retryTask, task]);
  return <Modal large open={open} loading={loading} title="Task details" onClose={() => onClose()} primaryAction={primaryAction}>{task && <>
    <Modal.Section><Stack2 spacing="extraLoose">
      <TextContainer>
        <Heading>Task ID</Heading>
        <p>{task.id}</p>
      </TextContainer>
      <TextContainer>
        <Heading>Type</Heading>
        <p>{task.taskDefinitionName}</p>
      </TextContainer>
      <TextContainer>
        <Heading>Status</Heading>
        <StatusBadge status={task.status} />
      </TextContainer>
    </Stack2></Modal.Section>
    <Modal.Section subdued><Stack2 vertical>
      <Heading>Logs</Heading>
      <LogViewer task={task} />
    </Stack2></Modal.Section>
  </>}</Modal>;
};

// src/provider.tsx
var Context = React3.createContext(null);
var TaskifyProvider = ({
  region,
  children,
  firebase
}) => {
  const [taskRef, setTaskRef] = React3.useState();
  const [modalOpen, setModalOpen] = React3.useState(false);
  const firestore = React3.useMemo(() => getFirestore(firebase), [firebase]);
  const functions = React3.useMemo(
    () => getFunctions(firebase, region),
    [firebase, region]
  );
  const viewTask = React3.useCallback(
    ({ taskPath }) => {
      setTaskRef(doc(firestore, taskPath));
      setModalOpen(true);
    },
    [firestore]
  );
  const contextValue = React3.useMemo(
    () => ({ viewTask, firebase, firestore, functions }),
    [viewTask, firebase, firestore]
  );
  return <Context.Provider value={contextValue}>
    {children}
    <TaskModal open={modalOpen} taskPath={taskRef == null ? void 0 : taskRef.path} onClose={() => setModalOpen(false)} />
  </Context.Provider>;
};
var useContext = () => React3.useContext(Context);
var useFirebase = () => useContext().firebase;
var useFirestore = () => useContext().firestore;
var useFunctions = () => useContext().functions;
var useViewTask = () => useContext().viewTask;

// src/hooks.tsx
var useDispatchTask = (stackName, taskDefinitionName) => {
  const viewTask = useViewTask();
  const functions = useFunctions();
  const dispatchTask = httpsCallable(
    functions,
    "taskifyDispatcher"
  );
  return React4.useCallback(
    async (input, context) => {
      const {
        data: { taskPath }
      } = await dispatchTask({
        stackName,
        taskDefinitionName,
        ...input ? { input } : {},
        ...context ? { context } : {}
      });
      viewTask({ taskPath });
      return { taskPath };
    },
    [stackName, taskDefinitionName, dispatchTask, viewTask]
  );
};
var useTask = (taskPath) => {
  const firestore = useFirestore();
  const refConverter = useRefConverter();
  const taskRef = taskPath ? doc2(firestore, taskPath).withConverter(
    refConverter
  ) : void 0;
  const [task, loading, error] = useDocumentData(taskRef);
  React4.useEffect(() => error && console.error(error), [error]);
  return { task, loading, error };
};
var useRetryTask = () => {
  const viewTask = useViewTask();
  const firestore = useFirestore();
  const functions = useFunctions();
  return React4.useCallback(
    async ({ originalTaskPath }) => {
      const taskRef = doc2(
        firestore,
        originalTaskPath
      );
      const task = (await getDoc(taskRef)).data();
      invariant(task, `there is no task at path ${originalTaskPath}`);
      const dispatchTask = httpsCallable(
        functions,
        "taskifyDispatcher"
      );
      const {
        data: { taskPath }
      } = await dispatchTask({
        stackName: task.stackName,
        taskDefinitionName: task.taskDefinitionName,
        ...task.input ? { input: task.input } : {},
        ...task.context ? { context: task.context } : {}
      });
      viewTask({ taskPath });
      return { taskPath };
    },
    [viewTask, firestore, functions]
  );
};
var useTaskLogs = ({
  taskPath,
  searchFromDate
}) => {
  const functions = useFunctions();
  const getLogs = httpsCallable(
    functions,
    "taskifyLogAccessor"
  );
  const [status, setStatus] = React4.useState();
  const [logEntries, setLogEntries] = React4.useState();
  const searchFromTimestamp = React4.useMemo(
    () => formatISO(searchFromDate),
    [searchFromDate]
  );
  const fetchLogs = React4.useCallback(async () => {
    const { data } = await getLogs({ taskPath, searchFromTimestamp });
    setStatus(data.status);
    setLogEntries(data.logEntries);
  }, [taskPath, searchFromTimestamp]);
  React4.useEffect(() => {
    if ("EMULATOR" === status)
      return;
    fetchLogs();
    const interval = setInterval(fetchLogs, 15e3);
    return () => clearInterval(interval);
  }, [status, fetchLogs]);
  return { status, logEntries };
};

// src/components/TaskList.tsx
import React5 from "react";
import { formatDistanceToNow } from "date-fns";
import { ResourceList } from "@usereactify/app";
import { Stack as Stack3, TextStyle as TextStyle2, EmptyState } from "@shopify/polaris";
import { collection, where } from "firebase/firestore";
var TaskList = ({ tasksPath }) => {
  const viewTask = useViewTask();
  const firestore = useFirestore();
  const tasksRef = React5.useMemo(
    () => collection(firestore, tasksPath ?? "tasks"),
    [firestore, tasksPath]
  );
  return <ResourceList tabs={tabs} query={tasksRef} sortOptions={sortOptions} renderItem={({ data: task }) => <Stack3 alignment="center">
    <p>{task.taskDefinitionName}</p>
    <StatusBadge status={task.status} />
    {task.createdAt && <TextStyle2 variation="subdued">{formatDistanceToNow(task.createdAt.toDate(), {
      addSuffix: true
    })}</TextStyle2>}
  </Stack3>} renderEmptyState={() => <EmptyState image="https://cdn.shopify.com/s/files/1/0262/4071/2726/files/emptystate-files.png"><p>There are no recent tasks to display.</p></EmptyState>} onClick={(task) => viewTask({ taskPath: task.ref.path })} />;
};
var sortOptions = [
  {
    direction: "desc",
    field: "createdAt",
    label: "Most recent"
  }
];
var tabs = [
  {
    id: "all",
    label: "All tasks",
    queryConstraints: []
  },
  {
    id: "failed",
    label: "Failed",
    queryConstraints: [where("status", "==", "FAILED")]
  },
  {
    id: "timeout",
    label: "Timeout",
    queryConstraints: [where("status", "==", "TIMEOUT")]
  }
];
export {
  Context,
  LogViewer,
  StatusBadge,
  TaskList,
  TaskModal,
  TaskifyProvider,
  useContext,
  useDispatchTask,
  useFirebase,
  useFirestore,
  useFunctions,
  useRetryTask,
  useTask,
  useTaskLogs,
  useViewTask
};
//# sourceMappingURL=index.js.map